import { Router } from '@angular/router';
import { LoggingService } from 'ionic-logging-service';
import { of, timer } from 'rxjs';
import { delay, filter, takeUntil, takeWhile } from 'rxjs/operators';
import * as jwtDecodeLib from 'jwt-decode';
import { CriticalError } from 'totvs-log-base-foundation';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { InAppBrowser } from '@ionic-native/in-app-browser/ngx';
import { Network } from '@ionic-native/network/ngx';
import { OAuthStorage, AuthConfig, JwksValidationHandler, OAuthService, OAuthModule } from 'angular-oauth2-oidc';
import { __awaiter } from 'tslib';
import { InjectionToken, Injectable, EventEmitter, Inject, NgModule } from '@angular/core';
import { Platform } from '@ionic/angular';
import { Storage } from '@ionic/storage';
import { StorageUtil } from 'totvs-log-mobile-foundation/src/storage-util';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const DefaultPopupFeatures = 'location=no,toolbar=no,zoom=no';
/** @type {?} */
const DefaultPopupTarget = '_blank';
// tslint:disable: variable-name
class CordovaPopupWindow {
    /**
     * @param {?} params
     */
    constructor(params) {
        this._exited = false;
        this._promise = new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this._resolve = resolve;
            this._reject = reject;
        }));
        this.features = params.popupWindowFeatures || DefaultPopupFeatures;
        this.target = params.popupWindowTarget || DefaultPopupTarget;
        this.redirect_uri = params.startUrl;
    }
    /**
     * @param {?} cordovaMetadata
     * @return {?}
     */
    _isInAppBrowserInstalled(cordovaMetadata) {
        return [
            'cordova-plugin-inappbrowser',
            'cordova-plugin-inappbrowser.inappbrowser',
            'org.apache.cordova.inappbrowser'
        ].some((/**
         * @param {?} name
         * @return {?}
         */
        (name) => {
            return cordovaMetadata.hasOwnProperty(name);
        }));
    }
    /**
     * @param {?} params
     * @return {?}
     */
    navigate(params) {
        if (!params || !params.url) {
            this._error('No url provided');
        }
        else {
            if (!window.cordova) {
                return this._error('cordova is undefined');
            }
            /** @type {?} */
            const cordovaMetadata = window.cordova.require('cordova/plugin_list')
                .metadata;
            if (this._isInAppBrowserInstalled(cordovaMetadata) === false) {
                return this._error('InAppBrowser plugin not found');
            }
            this._popup = cordova.InAppBrowser.open(params.url, this.target, this.features);
            if (this._popup) {
                this._exitCallbackEvent = this._exitCallback.bind(this);
                this._errorCallbackEvent = this._errorCallback.bind(this);
                this._loadStartCallbackEvent = this._loadStartCallback.bind(this);
                this._popup.addEventListener('exit', this._exitCallbackEvent, false);
                this._popup.addEventListener('loaderror', this._errorCallbackEvent, false);
                this._popup.addEventListener('loadstart', this._loadStartCallbackEvent, false);
            }
            else {
                this._error('Error opening popup window');
            }
        }
        return this.promise;
    }
    /**
     * @return {?}
     */
    get promise() {
        return this._promise;
    }
    /**
     * @param {?} message
     * @return {?}
     */
    _errorCallback(message) {
        console.error(message);
        if (!message.url || message.url.indexOf(this.redirect_uri) === -1) {
            this._error(message);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    _loadStartCallback(event) {
        if (event.url.indexOf(this.redirect_uri) === 0) {
            this._success({ urlFragment: event.url });
        }
    }
    /**
     * @return {?}
     */
    get exited() {
        if (!this._popup) {
            return this._exited;
        }
        else {
            return false;
        }
    }
    /**
     * @param {?} message
     * @return {?}
     */
    _exitCallback(message) {
        console.error(message);
        if (message.type === 'exit') {
            this._exited = true;
        }
        this._error(message);
    }
    /**
     * @param {?} data
     * @return {?}
     */
    _success(data) {
        this._cleanup();
        this._resolve(data);
    }
    /**
     * @param {?} message
     * @return {?}
     */
    _error(message) {
        this._cleanup();
        this._reject(new Error(message));
    }
    /**
     * @return {?}
     */
    close() {
        this._cleanup();
    }
    /**
     * @return {?}
     */
    _cleanup() {
        if (this._popup) {
            this._popup.removeEventListener('exit', this._exitCallbackEvent, false);
            this._popup.removeEventListener('loadstart', this._loadStartCallbackEvent, false);
            this._popup.close();
        }
        this._popup = null;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const OAUTH_ANGULAR_CONFIG = new InjectionToken('OAuthAngularConfig');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Responsável por guardar o usuário e tenant da sessão
 */
class OAuthAngularSessionService {
    /**
     * @return {?}
     */
    get storageName() {
        /** @type {?} */
        let storageUniqueName = this.tenant.shortNameTenant;
        if (this.user) {
            storageUniqueName += this.user.userShortName;
        }
        return storageUniqueName;
    }
}
OAuthAngularSessionService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OAuthAngularStorageSessionService extends OAuthStorage {
    /**
     * @param {?} session
     */
    constructor(session) {
        super();
        this.session = session;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getItem(key) {
        return window.localStorage.getItem(this.getKey(key));
    }
    /**
     * @param {?} key
     * @return {?}
     */
    removeItem(key) {
        window.localStorage.removeItem(this.getKey(key));
    }
    /**
     * @param {?} key
     * @param {?} data
     * @return {?}
     */
    setItem(key, data) {
        window.localStorage.setItem(this.getKey(key), data);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getKey(key) {
        return this.session.tenant
            ? this.session.tenant.shortNameTenant + '_' + key
            : key;
    }
}
OAuthAngularStorageSessionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OAuthAngularStorageSessionService.ctorParameters = () => [
    { type: OAuthAngularSessionService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class TenantService {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const jwtDecode = jwtDecodeLib;
// tslint:disable: no-string-literal
class UserInfoRac {
    /**
     * @private
     * @param {?} userId
     * @param {?} userShortName
     * @param {?} userFullName
     * @param {?} tenantId
     * @param {?} tenantShortName
     * @param {?} tenantFullName
     * @param {?} roles
     * @param {?} token
     */
    constructor(userId, userShortName, userFullName, tenantId, tenantShortName, tenantFullName, roles, token) {
        this.userId = userId;
        this.userShortName = userShortName;
        this.userFullName = userFullName;
        this.tenantId = tenantId;
        this.tenantShortName = tenantShortName;
        this.tenantFullName = tenantFullName;
        this.roles = roles;
        this.token = token;
    }
    /**
     * @param {?} jwt
     * @return {?}
     */
    static ofJwt(jwt) {
        /** @type {?} */
        let jsonToken;
        try {
            jsonToken = jwtDecode(jwt);
        }
        catch (error) {
            console.error(error);
            throw new CriticalError('Não foi possível autorizar o token por erro de decodificação');
        }
        try {
            /** @type {?} */
            let roles = [];
            if (jsonToken['role']) {
                if (!Array.isArray(jsonToken['role'])) {
                    jsonToken['role'] = [jsonToken['role']];
                }
                roles = jsonToken['role'];
            }
            return new UserInfoRac(jsonToken['sub'], jsonToken['name'][0], jsonToken[UserInfoRac.USER_FULL_NAME_CLAIM], jsonToken[UserInfoRac.TENANT_ID_CLAIM], jsonToken[UserInfoRac.TENANT_NAME_CLAIM], jsonToken[UserInfoRac.TENANT_FULL_NAME_CLAIM], roles, jwt);
        }
        catch (error) {
            console.error(error);
            throw new CriticalError('Não foi possível autorizar o token por erro de conversão');
        }
    }
}
UserInfoRac.USER_FULL_NAME_CLAIM = 'http://www.tnf.com/identity/claims/userFullname';
UserInfoRac.TENANT_ID_CLAIM = 'http://www.tnf.com/identity/claims/tenantId';
UserInfoRac.TENANT_NAME_CLAIM = 'http://www.tnf.com/identity/claims/tenantName';
UserInfoRac.TENANT_FULL_NAME_CLAIM = 'http://www.tnf.com/identity/claims/tenantFullName';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable: no-string-literal
class OAuthAngularService {
    /**
     * @param {?} oAuthAngularConfig
     * @param {?} loggingService
     * @param {?} network
     * @param {?} oauth
     * @param {?} session
     * @param {?} tenantPersistence
     */
    constructor(oAuthAngularConfig, loggingService, network, oauth, session, tenantPersistence) {
        this.oAuthAngularConfig = oAuthAngularConfig;
        this.loggingService = loggingService;
        this.network = network;
        this.oauth = oauth;
        this.session = session;
        this.tenantPersistence = tenantPersistence;
        this.isBackButton = false;
        this.tokenExpiredEvent = new EventEmitter();
        this.authorizedEvent = new EventEmitter();
        this.unauthorizedEvent = new EventEmitter();
        oauth.tokenValidationHandler = new JwksValidationHandler();
    }
    /**
     * @return {?}
     */
    authorize() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.session.tenant || !this.session.tenant.shortNameTenant || this.session.tenant.shortNameTenant === '') {
                return false;
            }
            /** @type {?} */
            const oAuthAngularConfig = new AuthConfig(this.oAuthAngularConfig);
            oAuthAngularConfig.issuer = oAuthAngularConfig.issuer.replace('{tenant}', this.session.tenant.shortNameTenant);
            if (!this.getAccessToken()) {
                this.oauth.configure(oAuthAngularConfig);
                yield this.oauth.loadDiscoveryDocumentAndTryLogin();
            }
            if (!this.getAccessToken()) {
                try {
                    yield this.loginFlow(oAuthAngularConfig);
                }
                catch (error) { }
            }
            else {
                yield this.gotTokenFlow(oAuthAngularConfig);
            }
            /** @type {?} */
            const authorized = this.getAccessToken() && this.getAccessToken().length > 0;
            return authorized;
        });
    }
    /**
     * @return {?}
     */
    logoutFlow() {
        this.teardownAutomaticSilentRefresh();
        this.oauth.logOut(true);
        /** @type {?} */
        const browser = new CordovaPopupWindow({
            startUrl: 'https://localhost/oidc',
            popupWindowFeatures: 'hidden=yes,clearcache=yes,clearsessioncache=yes'
        });
        return browser.navigate({
            url: 'https://localhost/oidc'
        }).then((/**
         * @return {?}
         */
        () => { })).catch(console.error);
    }
    /**
     * @private
     * @return {?}
     */
    getAccessToken() {
        if (this.isExpired()) {
            return '';
        }
        return this.oauth.getAccessToken();
    }
    /**
     * @private
     * @return {?}
     */
    getUser() {
        if (!this.getAccessToken()) {
            return this.session.user;
        }
        return UserInfoRac.ofJwt(this.getAccessToken());
    }
    /**
     * @private
     * @return {?}
     */
    isExpired() {
        return (!this.oauth.getAccessTokenExpiration() ||
            this.oauth.getAccessTokenExpiration() < new Date().getTime() + 1000); // Folga para considerar expirado com um segundo de antecedência
    }
    /**
     * @private
     * @param {?} oAuthAngularConfig
     * @return {?}
     */
    silentRefresh(oAuthAngularConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            this.oauth.configure(oAuthAngularConfig);
            yield this.oauth.loadDiscoveryDocumentAndTryLogin();
            return this.loginFlow(oAuthAngularConfig, this.oauth['createLoginUrl'](null, null, oAuthAngularConfig.silentRefreshRedirectUri || oAuthAngularConfig.redirectUri, true), 'yes');
        });
    }
    /**
     * @private
     * @param {?} authConfig
     * @return {?}
     */
    setupAutomaticSilentRefresh(authConfig) {
        if (!this.silentRenew) {
            this.silentRenew = this.tokenExpiredEvent.subscribe((/**
             * @return {?}
             */
            () => {
                this.silentRefresh(authConfig).catch((/**
                 * @return {?}
                 */
                () => {
                    timer(300000, 300000)
                        .pipe(takeUntil(this.oauth.events.pipe(filter((/**
                     * @param {?} x
                     * @return {?}
                     */
                    x => x.type === 'token_refreshed' ||
                        x.type === 'token_received' ||
                        x.type === 'silently_refreshed')))), takeWhile((/**
                     * @return {?}
                     */
                    () => this.silentRenew !== undefined)))
                        .subscribe((/**
                     * @return {?}
                     */
                    () => {
                        this.silentRefresh(authConfig).catch((/**
                         * @return {?}
                         */
                        () => { }));
                    }));
                }));
            }));
        }
    }
    /**
     * @return {?}
     */
    teardownAutomaticSilentRefresh() {
        if (this.silentRenew) {
            this.silentRenew.unsubscribe();
            this.silentRenew = undefined;
        }
    }
    /**
     * @private
     * @param {?} user
     * @return {?}
     */
    setCurrentTenantFromUser(user) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const tenant = {
                id: user.tenantId,
                name: user.tenantFullName,
                shortNameTenant: user.tenantShortName
            };
            this.session.tenant = tenant;
            /** @type {?} */
            const tenantAdded = yield this.tenantPersistence.addTenant(tenant);
            yield this.tenantPersistence.setCurrentTenant(tenantAdded);
        });
    }
    /**
     * @private
     * @param {?} auth
     * @param {?=} urlAuth
     * @param {?=} hidden
     * @return {?}
     */
    loginFlow(auth, urlAuth = this.oauth['createLoginUrl'](), hidden = 'no') {
        return __awaiter(this, void 0, void 0, function* () {
            this.isBackButton = false;
            /** @type {?} */
            const url = yield urlAuth;
            /** @type {?} */
            const logger = this.loggingService.getLogger('OAuthAngularService');
            /** @type {?} */
            const browser = new CordovaPopupWindow({
                startUrl: auth.redirectUri,
                popupWindowFeatures: hidden === 'yes' ? 'hidden=yes' : undefined
            });
            /** @type {?} */
            let urlFragment;
            try {
                urlFragment = yield browser.navigate({ url });
            }
            catch (e) {
                if (!browser.exited) {
                    logger.error(this.session.storageName, 'loginFlow', e);
                    throw e;
                }
            }
            this.isBackButton = browser.exited;
            try {
                yield this.oauth.tryLogin({
                    customHashFragment: '#' + urlFragment.urlFragment.split('#')[1]
                });
            }
            catch (error) {
                console.error(error);
            }
            if (this.getAccessToken()) {
                yield this.gotTokenFlow(auth);
                /** @type {?} */
                const authorized = this.getAccessToken() && this.getAccessToken().length > 0;
                if (authorized) {
                    this.authorizedEvent.emit();
                }
                else {
                    this.unauthorizedEvent.emit();
                }
            }
        });
    }
    /**
     * @param {?} auth
     * @return {?}
     */
    gotTokenFlow(auth) {
        return __awaiter(this, void 0, void 0, function* () {
            of({}).pipe(delay((this.oauth.getAccessTokenExpiration() - new Date().getTime()) * 0.95))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.tokenExpiredEvent.emit();
            }));
            /** @type {?} */
            const access = this.getAccessToken() && this.getAccessToken().length > 0;
            if (access) {
                yield this.setCurrentTenantFromUser(this.getUser());
                this.session.user = this.getUser();
                this.setupAutomaticSilentRefresh(auth);
            }
            if (!this.networkConnect) {
                this.networkConnect = this.network.onConnect().pipe(filter((/**
                 * @return {?}
                 */
                () => this.silentRenew !== undefined))).subscribe((/**
                 * @return {?}
                 */
                () => {
                    this.silentRefresh(auth).catch((/**
                     * @return {?}
                     */
                    () => { }));
                }));
            }
        });
    }
}
OAuthAngularService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OAuthAngularService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [OAUTH_ANGULAR_CONFIG,] }] },
    { type: LoggingService },
    { type: Network },
    { type: OAuthService },
    { type: OAuthAngularSessionService },
    { type: TenantService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Implementação de guard com uso do serviço de autenticação padrão
 */
class OAuthAngularGuard {
    /**
     * @param {?} authService
     * @param {?} router
     */
    constructor(authService, router) {
        this.authService = authService;
        this.router = router;
    }
    /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     * @return {?}
     */
    canActivate() {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const authorized = yield this.authService.authorize();
            if (!authorized && this.authService.oAuthAngularConfig.unathorizedRedirectRoute) {
                return this.router.parseUrl(`/${this.authService.oAuthAngularConfig.unathorizedRedirectRoute}`);
            }
            else {
                return authorized;
            }
        });
    }
}
OAuthAngularGuard.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OAuthAngularGuard.ctorParameters = () => [
    { type: OAuthAngularService },
    { type: Router }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OAuthAngularInterceptor {
    /**
     * @param {?} session
     */
    constructor(session) {
        this.session = session;
    }
    /**
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    intercept(req, next) {
        if (this.session.tenant && this.session.user) {
            return next.handle(req.clone({
                url: req.url.replace('{tenant}', this.session.tenant.shortNameTenant),
                setHeaders: {
                    Authorization: 'Bearer ' + this.session.user.token
                }
            }));
        }
        else {
            return next.handle(req);
        }
    }
}
OAuthAngularInterceptor.decorators = [
    { type: Injectable }
];
/** @nocollapse */
OAuthAngularInterceptor.ctorParameters = () => [
    { type: OAuthAngularSessionService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WithoutTenantStorageService extends TenantService {
    /**
     * @return {?}
     */
    getCurrentTenant() {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.resolve(null);
        });
    }
    /**
     * @param {?} currentTenant
     * @return {?}
     */
    setCurrentTenant(currentTenant) {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.resolve(null);
        });
    }
    /**
     * @param {?} tenant
     * @return {?}
     */
    addTenant(tenant) {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.resolve(tenant);
        });
    }
}
WithoutTenantStorageService.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OAuthAngularModule {
    /**
     * @param {?} oAuthAngularConfig
     * @return {?}
     */
    static forRoot(oAuthAngularConfig) {
        return {
            ngModule: OAuthAngularModule,
            providers: [
                InAppBrowser,
                Network,
                OAuthAngularSessionService,
                OAuthAngularService,
                OAuthAngularGuard,
                {
                    provide: TenantService,
                    useClass: WithoutTenantStorageService
                },
                {
                    provide: OAuthStorage,
                    useClass: OAuthAngularStorageSessionService
                },
                {
                    provide: OAUTH_ANGULAR_CONFIG,
                    useValue: oAuthAngularConfig
                }
            ]
        };
    }
}
OAuthAngularModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    OAuthModule.forRoot()
                ],
                exports: [
                    OAuthModule
                ],
                providers: [
                    {
                        provide: HTTP_INTERCEPTORS,
                        useClass: OAuthAngularInterceptor,
                        multi: true,
                    },
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MultiTenantService extends TenantService {
    /**
     * Método construtor responsável por inicializar o serviço
     * @param {?} platform Serviço relacionado a plataforma
     * @param {?} storage Serviço relacionado ao storage
     */
    constructor(platform, storage) {
        super();
        this.storage = storage;
        /**
         * @ignore
         * Indica se a plataforma é cordova
         */
        this.isCordova = false;
        this.ready = new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        resolve => {
            this.readyFn = resolve;
        }));
        platform.ready().then((/**
         * @return {?}
         */
        () => {
            this.isCordova = platform.is('cordova');
            if (this.isCordova) {
                this.tenantsStorage = new StorageUtil(this.storage);
                this.tenantsStorage
                    .config({
                    name: 'Tenants',
                    id: 'shortNameTenant',
                    exclusive: false,
                    lazy: false,
                    initFn: (/**
                     * @return {?}
                     */
                    () => []),
                })
                    .then((/**
                 * @return {?}
                 */
                () => { }));
                this.currentTenantStorage = new StorageUtil(this.storage);
                this.currentTenantStorage
                    .config({
                    name: 'CurrentTenant',
                    id: 'shortNameTenant',
                    exclusive: false,
                    lazy: true,
                    initFn: (/**
                     * @return {?}
                     */
                    () => undefined),
                })
                    .then((/**
                 * @return {?}
                 */
                () => { }));
            }
            this.readyFn();
        }));
    }
    /**
     * @return {?}
     */
    get tenants() {
        return this.tenantsStorage ? this.tenantsStorage.data : [];
    }
    /**
     * @return {?}
     */
    get isReady() {
        return this.ready;
    }
    /**
     * @return {?}
     */
    getCurrentTenant() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.ready;
            /** @type {?} */
            const currentTenant = (/** @type {?} */ ((yield this.currentTenantStorage.read())));
            try {
                if (yield this.tenantsStorage.get(currentTenant.shortNameTenant)) {
                    return currentTenant;
                }
            }
            catch (error) {
                this.currentTenantStorage.data = undefined;
                yield this.currentTenantStorage.updateStorage();
                return undefined;
            }
        });
    }
    /**
     * @param {?} currentTenant
     * @return {?}
     */
    setCurrentTenant(currentTenant) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.ready;
            yield this.currentTenantStorage.read();
            if (!this.currentTenantStorage.data) {
                this.currentTenantStorage.data = currentTenant;
            }
            this.currentTenantStorage.data = currentTenant;
            yield this.currentTenantStorage.updateStorage();
        });
    }
    /**
     * @param {?} tenant
     * @return {?}
     */
    addTenant(tenant) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.ready;
            /** @type {?} */
            const tenants = (/** @type {?} */ ((yield this.tenantsStorage.read())));
            // Verificação de duplicidade de tenant
            if (tenants && tenants.length > 0) {
                tenants.forEach((/**
                 * @param {?} tenantFromStorage
                 * @param {?} index
                 * @return {?}
                 */
                (tenantFromStorage, index) => {
                    if (tenantFromStorage.shortNameTenant === tenant.shortNameTenant) {
                        tenants.splice(index, 1);
                    }
                }));
            }
            this.tenantsStorage.data = tenants;
            this.tenantsStorage.data.push(tenant);
            this.sortTenantsByShortName();
            yield this.tenantsStorage.updateStorage();
            return tenant;
        });
    }
    /**
     * @param {?} tenant
     * @return {?}
     */
    deleteTenant(tenant) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.ready;
            try {
                yield this.tenantsStorage.delete(tenant.shortNameTenant);
                yield this.tenantsStorage.read();
            }
            catch (error) {
                console.error(error);
            }
        });
    }
    /**
     * @private
     * @return {?}
     */
    sortTenantsByShortName() {
        /** @type {?} */
        const sortBy = (/**
         * @param {?} fn
         * @return {?}
         */
        fn => (/**
         * @param {?} a
         * @param {?} b
         * @return {?}
         */
        (a, b) => -(fn(a) < fn(b)) || +(fn(a) > fn(b))));
        /** @type {?} */
        const getShortName = (/**
         * @param {?} o
         * @return {?}
         */
        o => o.shortNameTenant);
        /** @type {?} */
        const sortByShortName = sortBy(getShortName);
        this.tenantsStorage.data.sort(sortByShortName);
    }
}
MultiTenantService.SHORT_NAME_TENANT_FIELD = 'tenantId';
MultiTenantService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
MultiTenantService.ctorParameters = () => [
    { type: Platform },
    { type: Storage }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SingleTenantService extends TenantService {
    /**
     * Método construtor responsável por inicializar o serviço
     * @param {?} platform Serviço relacionado a plataforma
     * @param {?} storage Serviço relacionado ao storage
     */
    constructor(platform, storage) {
        super();
        this.storage = storage;
        /**
         * @ignore
         * Indica se a plataforma é cordova
         */
        this.isCordova = false;
        this.ready = new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        resolve => {
            this.readyFn = resolve;
        }));
        platform.ready().then((/**
         * @return {?}
         */
        () => {
            this.isCordova = platform.is('cordova');
            if (this.isCordova) {
                this.currentTenantStorage = new StorageUtil(this.storage);
                this.currentTenantStorage
                    .config({
                    name: 'CurrentTenant',
                    id: 'shortNameTenant',
                    exclusive: false,
                    lazy: true,
                    initFn: (/**
                     * @return {?}
                     */
                    () => undefined),
                })
                    .then((/**
                 * @return {?}
                 */
                () => { }));
            }
            this.readyFn();
        }));
    }
    /**
     * @return {?}
     */
    get isReady() {
        return this.ready;
    }
    /**
     * @return {?}
     */
    getCurrentTenant() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.ready;
            /** @type {?} */
            const currentTenant = (/** @type {?} */ ((yield this.currentTenantStorage.read())));
            return currentTenant;
        });
    }
    /**
     * @param {?} currentTenant
     * @return {?}
     */
    setCurrentTenant(currentTenant) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.ready;
            yield this.currentTenantStorage.read();
            if (!this.currentTenantStorage.data) {
                this.currentTenantStorage.data = currentTenant;
            }
            this.currentTenantStorage.data = currentTenant;
            yield this.currentTenantStorage.updateStorage();
        });
    }
    /**
     * @param {?} tenant
     * @return {?}
     */
    addTenant(tenant) {
        return __awaiter(this, void 0, void 0, function* () {
            this.setCurrentTenant(tenant);
            return tenant;
        });
    }
}
SingleTenantService.SHORT_NAME_TENANT_FIELD = 'tenantId';
SingleTenantService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SingleTenantService.ctorParameters = () => [
    { type: Platform },
    { type: Storage }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { OAUTH_ANGULAR_CONFIG, OAuthAngularSessionService, OAuthAngularStorageSessionService, OAuthAngularGuard, OAuthAngularInterceptor, OAuthAngularModule, OAuthAngularService, CordovaPopupWindow, MultiTenantService, SingleTenantService, TenantService, WithoutTenantStorageService, UserInfoRac };

//# sourceMappingURL=totvs-log-mobile-foundation-src-oauth-angular.js.map