import { __awaiter } from 'tslib';
import { TranslateService, TranslateModule, TranslateLoader } from '@ngx-translate/core';
import { TranslateHttpLoader } from '@ngx-translate/http-loader';
import { HttpClient, HTTP_INTERCEPTORS } from '@angular/common/http';
import { CommonModule, DatePipe } from '@angular/common';
import { ReplaySubject } from 'rxjs';
import { map, take } from 'rxjs/operators';
import { Injectable, Inject, InjectionToken, NgModule, Pipe, APP_INITIALIZER, Injector } from '@angular/core';
import { AlertController, ToastController, LoadingController } from '@ionic/angular';
import { CriticalError, I18nBaseService, AbstractShowMessage, ShowMessageLinkActionType, ShowMessageType, MessageDisplayerService, ApiDateTimeService, LoadingDefault, HttpInterceptorBaseService, MessageUtils, DefaultDateViewConverterService, DateViewConverter, DateTimeModule, TimeViewConverter, DefaultTimeViewConverterService } from 'totvs-log-base-foundation';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço utilizado para carregar as literais
 */
class IntlLiteralsLoaderService {
    /**
     * Método construtor da classe
     * translate
     * @param {?} translate
     */
    constructor(translate) {
        this.translate = translate;
        /**
         * Responsável por receber as configurações do serviço de tradução para carregar as literais
         */
        this.mobileOptions = { language: 'pt-br', url: '' };
    }
    /**
     * Método responsável por setar as opções e retornar a literal atualizada
     * options
     * @param {?} options
     * @return {?}
     */
    updateOptions(options) {
        try {
            Object.assign(this.mobileOptions, options);
            return this.load();
        }
        catch (error) {
            throw new CriticalError(error);
        }
    }
    /**
     * Método responsável por setar o carregamento e retornar a literal atualizada
     * @return {?}
     */
    load() {
        return this.translate.getTranslation(this.mobileOptions.language)
            .pipe(map((/**
         * @param {?} res
         * @return {?}
         */
        (res) => res)));
    }
}
IntlLiteralsLoaderService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
IntlLiteralsLoaderService.ctorParameters = () => [
    { type: TranslateService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Token de configuração da url de internacionalização
 * @type {?}
 */
const INTL_CONFIG = new InjectionToken('Configurações da internacionalização');
/**
 * Serviço de internacionalização da aplicação
 */
class IntlService extends I18nBaseService {
    /**
     * Método construtor que inicializa a classe
     * translate Serviço de internacionalização
     * @param {?} config
     * @param {?} intlLiteralsLoader
     */
    constructor(config, intlLiteralsLoader) {
        super(intlLiteralsLoader);
        /**
         * Atributo de opções de internacionalização
         */
        this.options = { language: 'pt-br', url: '' };
        /** @type {?} */
        let matchedNavigatorAppLanguage;
        if (config.supportedLanguages) {
            matchedNavigatorAppLanguage = config.supportedLanguages.find((/**
             * @param {?} appSupportedLanguage
             * @return {?}
             */
            appSupportedLanguage => {
                return appSupportedLanguage.language === navigator.language;
            }));
        }
        if (!matchedNavigatorAppLanguage) {
            matchedNavigatorAppLanguage = { language: 'pt-br' };
        }
        this.options.language = matchedNavigatorAppLanguage.language.toLowerCase();
    }
}
IntlService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
IntlService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [INTL_CONFIG,] }] },
    { type: IntlLiteralsLoaderService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável pela apresentação de mensagens
 */
class ShowMessageService extends AbstractShowMessage {
    /**
     * Método construtor que inicializa a classe
     * toastCtrl Serviço de TOAST
     * alertCtrl Serviço de Alerta
     * i18n Serviço de internacionalização
     * @param {?} toastCtrl
     * @param {?} alertCtrl
     */
    constructor(toastCtrl, alertCtrl) {
        super();
        this.toastCtrl = toastCtrl;
        this.alertCtrl = alertCtrl;
    }
    /**
     * Método responsável por apresentar uma mensagem
     * @param {?} showMessageOptions
     * @return {?}
     */
    displayMessage(showMessageOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            switch (showMessageOptions.messageType) {
                case ShowMessageType.NotificationSuccess:
                case ShowMessageType.NotificationError:
                case ShowMessageType.NotificationWarning:
                case ShowMessageType.NotificationInformation:
                    yield this.showNotification(showMessageOptions);
                    break;
                case ShowMessageType.DialogAlert:
                case ShowMessageType.DialogConfirmation:
                    yield this.showDialog(showMessageOptions);
                    break;
                default:
                    throw new Error('Tipo de mensagem inválido');
            }
        });
    }
    /**
     * Método responsável por apresentar uma mensagem de notificação
     * @private
     * @param {?} showMessageOptions
     * @return {?}
     */
    showNotification(showMessageOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const toast = yield this.toastCtrl.create({
                message: showMessageOptions.messageText,
                color: this.getColorByMessageType(showMessageOptions.messageType),
                duration: showMessageOptions.messageLinkActionType ===
                    ShowMessageLinkActionType.No
                    ? 3000
                    : 10000,
                position: 'bottom',
                showCloseButton: showMessageOptions.messageLinkActionType !==
                    ShowMessageLinkActionType.No,
                closeButtonText: showMessageOptions.messageLinkLabel
            });
            toast.onDidDismiss().then((/**
             * @return {?}
             */
            () => {
                if (showMessageOptions.messageLinkActionType ===
                    ShowMessageLinkActionType.LinkNewTab) {
                    this.openLink(showMessageOptions.messageLinkAction);
                }
                else if (showMessageOptions.messageLinkActionType ===
                    ShowMessageLinkActionType.Method &&
                    showMessageOptions.messageLinkAction) {
                    showMessageOptions.messageLinkAction();
                }
            }));
            yield toast.present();
        });
    }
    /**
     * Método responsável por apresentar uma mensagem de diálogo
     * @private
     * @param {?} showMessageOptions
     * @return {?}
     */
    showDialog(showMessageOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const buttons = [];
            /** @type {?} */
            let alert;
            if (showMessageOptions.messageCancelLabel &&
                showMessageOptions.messageCancelLabel.trim() !== '' &&
                showMessageOptions.messageType === ShowMessageType.DialogConfirmation) {
                buttons.push({
                    text: showMessageOptions.messageCancelLabel,
                    handler: (/**
                     * @return {?}
                     */
                    () => {
                        alert.dismiss(false);
                        if (showMessageOptions.messageCancelAction) {
                            showMessageOptions.messageCancelAction();
                        }
                        return false;
                    })
                });
            }
            if (showMessageOptions.messageConfirmLabel &&
                showMessageOptions.messageConfirmLabel.trim() !== '') {
                buttons.push({
                    text: showMessageOptions.messageConfirmLabel,
                    handler: (/**
                     * @return {?}
                     */
                    () => {
                        alert.dismiss(true);
                        if (showMessageOptions.messageConfirmAction) {
                            showMessageOptions.messageConfirmAction();
                        }
                        return true;
                    })
                });
            }
            alert = yield this.alertCtrl.create({
                message: showMessageOptions.messageDetails,
                header: showMessageOptions.messageTitle,
                subHeader: showMessageOptions.messageText,
                buttons
            });
            yield alert.present();
        });
    }
    /**
     * Método responsável pela abertura de um link
     * @private
     * @param {?} link
     * @return {?}
     */
    openLink(link) {
        link = link.indexOf('http://') === -1 ? `http://${link}` : link;
        window.open(link, '_blank');
    }
    /**
     * @private
     * @param {?} type
     * @return {?}
     */
    getColorByMessageType(type) {
        switch (type) {
            case ShowMessageType.NotificationSuccess:
                return 'success';
            case ShowMessageType.NotificationError:
                return 'danger';
            case ShowMessageType.NotificationWarning:
                return 'warning';
            default:
                return undefined;
        }
    }
}
ShowMessageService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ShowMessageService.ctorParameters = () => [
    { type: ToastController },
    { type: AlertController }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ShowMessageModule {
}
ShowMessageModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [],
                exports: [],
                providers: [
                    ShowMessageService,
                    MessageDisplayerService,
                    {
                        provide: AbstractShowMessage,
                        useClass: ShowMessageService
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Pipe de internacionalização da aplicação
 */
class I18NPipe {
    /**
     * Método construtor que inicializa a classe
     * i18nService Serviço de internacionalização
     * @param {?} i18nService
     */
    constructor(i18nService) {
        this.i18nService = i18nService;
    }
    /**
     * Método responsável pela transformação da string
     * query
     * data
     * @param {?} query
     * @param {?} data
     * @return {?}
     */
    transform(query, data) {
        if (!query || query.length === 0) {
            return '';
        }
        /** @type {?} */
        const ret = this.cached(query, data);
        if (ret) {
            return ret;
        }
        if (!data) {
            data = [''];
        }
        else if (!Array.isArray(data)) {
            data = [data];
        }
        return this.i18nService.format(data, query);
    }
    /**
     * Método responsável por retornar o que está em cache
     * query
     * args
     * @private
     * @param {?} query
     * @param {...?} args
     * @return {?}
     */
    cached(query, ...args) {
        return '';
    }
}
I18NPipe.decorators = [
    { type: Pipe, args: [{ name: 'format' },] }
];
/** @nocollapse */
I18NPipe.ctorParameters = () => [
    { type: I18nBaseService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const i18nFactory = (/**
 * @param {?} i18n
 * @param {?} config
 * @return {?}
 */
(i18n, config) => {
    return (/**
     * @return {?}
     */
    () => new Promise((/**
     * @param {?} resolve
     * @return {?}
     */
    resolve => {
        if (config.lazy) {
            resolve(true);
        }
        else {
            i18n.updateOptions({}).subscribe((/**
             * @return {?}
             */
            () => {
                resolve(true);
            }), (/**
             * @param {?} error
             * @return {?}
             */
            (error) => {
                console.error(error);
                resolve(false);
            }));
        }
    })));
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Função responsável por indicar o diretório que contém os arquivos de tradução
 * http
 * @param {?} http
 * @return {?}
 */
function createTranslateLoader(http) {
    return new TranslateHttpLoader(http, './assets/i18n/', '.json');
}
const ɵ0 = i18nFactory;
/**
 * Módulo responsável pela configuração da internacionalização da aplicação
 */
class IntlModule {
}
IntlModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    TranslateModule.forRoot({
                        loader: {
                            provide: TranslateLoader,
                            useFactory: createTranslateLoader,
                            deps: [HttpClient],
                        },
                    }),
                ],
                declarations: [I18NPipe],
                exports: [TranslateModule, I18NPipe],
                providers: [
                    IntlLiteralsLoaderService,
                    {
                        provide: I18nBaseService,
                        useClass: IntlService,
                    },
                    {
                        provide: APP_INITIALIZER,
                        useFactory: ɵ0,
                        deps: [I18nBaseService, INTL_CONFIG],
                        multi: true,
                    },
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável por fornecer atributos e métodos que
 * poderão ser utilizados em toda a aplicação
 */
class GlobalService {
    /**
     * Método construtor que inicializa o serviço
     * i18n Serviço de internacionalização
     * msg Serviço de mensageria para usuário
     * date Serviço de formatação de data
     * @param {?} i18n
     * @param {?} msg
     * @param {?} loading
     * @param {?} date
     */
    constructor(i18n, msg, loading, date) {
        this.i18n = i18n;
        this.msg = msg;
        this.loading = loading;
        this.date = date;
    }
}
GlobalService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
GlobalService.ctorParameters = () => [
    { type: I18nBaseService },
    { type: MessageDisplayerService },
    { type: LoadingDefault },
    { type: ApiDateTimeService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço utilizado para realizar o tratamento das respostas
 */
class DefaultHttpInterceptorService extends HttpInterceptorBaseService {
    /**
     * Método construtor da classe
     * inj
     * @param {?} inj
     */
    constructor(inj) {
        super();
        this.inj = inj;
    }
    /**
     * Método responsável por realizar o tratamento de respostas de sucesso
     * response
     * @param {?} response
     * @return {?}
     */
    interceptResponse(response) {
        this.msg = this.inj.get(MessageDisplayerService);
        if (response.body && response.body.totvs_messages) {
            if (response.body.totvs_messages instanceof Array) {
                /** @type {?} */
                const messages = response.body.totvs_messages;
                for (const message of messages) {
                    this.showTotvsMessage(message);
                }
            }
            else {
                this.showTotvsMessage((/** @type {?} */ (response.body.totvs_messages)));
            }
        }
    }
    /**
     * Método responsável por realizar o tratamento de respostas de erro
     * response
     * request
     * @param {?} response
     * @param {?} request
     * @return {?}
     */
    interceptError(response, request) {
        /** @type {?} */
        const error = (/** @type {?} */ (response.error));
        if (error && error.message && !HttpInterceptorBaseService.isErrorNotificationDisabled(request)) {
            /** @type {?} */
            const title = HttpInterceptorBaseService.titleFromTotvsError(error);
            /** @type {?} */
            const detail = HttpInterceptorBaseService.detailFromTotvsError(error);
            this.showTotvsMessage({
                type: 'error',
                code: title,
                detail
            });
        }
    }
    /**
     * Método responsável por mostrar a mensagem
     * message
     * @param {?} message
     * @return {?}
     */
    showTotvsMessage(message) {
        /** @type {?} */
        const messageType = MessageUtils.showMessageTypeFromTotvsMessage(message);
        this.msg.displayMessage({
            messageType,
            messageText: message.code,
            messageDetails: message.detail
        });
    }
    /**
     * Método responsável por realizar o tratamento da requisição/retorno
     * req
     * next
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    intercept(req, next) {
        return super.intercept(req, next);
    }
}
DefaultHttpInterceptorService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
DefaultHttpInterceptorService.ctorParameters = () => [
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InterceptorModule {
}
InterceptorModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                exports: [],
                providers: [
                    DefaultHttpInterceptorService,
                    {
                        provide: HTTP_INTERCEPTORS,
                        useClass: DefaultHttpInterceptorService,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateTimeModule$1 {
}
DateTimeModule$1.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [
                    CommonModule,
                    DateTimeModule
                ],
                exports: [],
                providers: [
                    {
                        provide: DateViewConverter,
                        useClass: DefaultDateViewConverterService
                    },
                    {
                        provide: TimeViewConverter,
                        useClass: DefaultTimeViewConverterService
                    },
                    DatePipe,
                    DefaultDateViewConverterService,
                    DefaultTimeViewConverterService,
                    ApiDateTimeService
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável pela apresentação de loading
 */
class ShowLoadingService extends LoadingDefault {
    /**
     * Método construtor que inicializa a classe
     * i18n Serviço de internacionalização
     * loadingController Serviço de loading
     * @param {?} i18n
     * @param {?} loadingController
     */
    constructor(i18n, loadingController) {
        super();
        this.i18n = i18n;
        this.loadingController = loadingController;
        this.loadingIsActiveProperty = new ReplaySubject(1);
        this.loadingActived = new ReplaySubject(1);
        this.thfContentTemplate = `
<div class="po-loading po-loading-icon">
  <span class="po-loading-icon-bar po-loading-icon-bar-1"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-2"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-3"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-4"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-5"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-6"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-7"></span>
  <span class="po-loading-icon-bar po-loading-icon-bar-8"></span>
</div>
<div class="po-font-text-small">{content}</div>`;
    }
    /**
     * @return {?}
     */
    get loadingIsActive() {
        return this.loadingIsActiveProperty;
    }
    /**
     * @return {?}
     */
    showLoading() {
        if (!this.active) {
            this.active = true;
            this.loadingIsActiveProperty.next(this.active);
            /** @type {?} */
            let content = '';
            if (this.loadingText) {
                content = this.loadingText.text;
            }
            this.loadingController
                .create({
                message: this.thfContentTemplate.replace('{content}', content),
                spinner: null
            })
                .then((/**
             * @param {?} loading
             * @return {?}
             */
            loading => {
                this.loading = loading;
                this.loading.present().then((/**
                 * @return {?}
                 */
                () => {
                    this.loadingActived.next();
                }));
            }));
        }
        return this.loadingActived.pipe(take(1));
    }
    /**
     * @return {?}
     */
    hideLoading() {
        if (this.active) {
            this.loadingActived.pipe(take(1)).subscribe((/**
             * @return {?}
             */
            () => {
                this.loadingText = undefined;
                this.loading.dismiss();
                this.active = false;
                this.loadingIsActiveProperty.next(this.active);
            }));
        }
    }
    /**
     * @param {?} loadingText
     * @return {?}
     */
    setLoadingText(loadingText) {
        this.loadingActived.pipe(take(1)).subscribe((/**
         * @return {?}
         */
        () => {
            setTimeout((/**
             * @return {?}
             */
            () => {
                /** @type {?} */
                const baseMessage = this.i18n.text(loadingText);
                if (this.loading) {
                    this.loading.message = this.thfContentTemplate.replace('{content}', baseMessage.text);
                }
                this.loadingText = baseMessage;
            }), 33);
        }));
    }
}
ShowLoadingService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
ShowLoadingService.ctorParameters = () => [
    { type: I18nBaseService },
    { type: LoadingController }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ShowLoadingModule {
}
ShowLoadingModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [],
                exports: [],
                providers: [
                    LoadingController,
                    {
                        provide: LoadingDefault,
                        useClass: ShowLoadingService
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FndModule {
    /**
     * @param {?} config
     * @return {?}
     */
    static forRoot(config) {
        return {
            ngModule: FndModule,
            providers: [GlobalService, { provide: INTL_CONFIG, useValue: config }],
        };
    }
}
FndModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    IntlModule,
                    ShowMessageModule,
                    InterceptorModule,
                    DateTimeModule$1,
                    ShowLoadingModule,
                ],
                declarations: [],
                exports: [
                    IntlModule,
                    ShowMessageModule,
                    InterceptorModule,
                    DateTimeModule$1,
                    ShowLoadingModule,
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FndModule, DateTimeModule$1 as DateTimeModule, GlobalService, InterceptorModule, DefaultHttpInterceptorService, i18nFactory, IntlLiteralsLoaderService, IntlModule, I18NPipe, IntlService, INTL_CONFIG, createTranslateLoader, ShowMessageModule, ShowMessageService, ShowLoadingService, ShowLoadingModule };

//# sourceMappingURL=totvs-log-mobile-foundation.js.map