import { Router } from '@angular/router';
import { LoggingService } from 'ionic-logging-service';
import { of, timer } from 'rxjs';
import { delay, filter, takeUntil, takeWhile } from 'rxjs/operators';
import * as jwtDecodeLib from 'jwt-decode';
import { CriticalError } from 'totvs-log-base-foundation';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { InAppBrowser } from '@ionic-native/in-app-browser/ngx';
import { Network } from '@ionic-native/network/ngx';
import { OAuthStorage, AuthConfig, JwksValidationHandler, OAuthService, OAuthModule } from 'angular-oauth2-oidc';
import { __extends, __awaiter, __generator } from 'tslib';
import { InjectionToken, Injectable, EventEmitter, Inject, NgModule } from '@angular/core';
import { Platform } from '@ionic/angular';
import { Storage } from '@ionic/storage';
import { StorageUtil } from 'totvs-log-mobile-foundation/src/storage-util';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var DefaultPopupFeatures = 'location=no,toolbar=no,zoom=no';
/** @type {?} */
var DefaultPopupTarget = '_blank';
// tslint:disable: variable-name
var  
// tslint:disable: variable-name
CordovaPopupWindow = /** @class */ (function () {
    function CordovaPopupWindow(params) {
        var _this = this;
        this._exited = false;
        this._promise = new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        function (resolve, reject) {
            _this._resolve = resolve;
            _this._reject = reject;
        }));
        this.features = params.popupWindowFeatures || DefaultPopupFeatures;
        this.target = params.popupWindowTarget || DefaultPopupTarget;
        this.redirect_uri = params.startUrl;
    }
    /**
     * @param {?} cordovaMetadata
     * @return {?}
     */
    CordovaPopupWindow.prototype._isInAppBrowserInstalled = /**
     * @param {?} cordovaMetadata
     * @return {?}
     */
    function (cordovaMetadata) {
        return [
            'cordova-plugin-inappbrowser',
            'cordova-plugin-inappbrowser.inappbrowser',
            'org.apache.cordova.inappbrowser'
        ].some((/**
         * @param {?} name
         * @return {?}
         */
        function (name) {
            return cordovaMetadata.hasOwnProperty(name);
        }));
    };
    /**
     * @param {?} params
     * @return {?}
     */
    CordovaPopupWindow.prototype.navigate = /**
     * @param {?} params
     * @return {?}
     */
    function (params) {
        if (!params || !params.url) {
            this._error('No url provided');
        }
        else {
            if (!window.cordova) {
                return this._error('cordova is undefined');
            }
            /** @type {?} */
            var cordovaMetadata = window.cordova.require('cordova/plugin_list')
                .metadata;
            if (this._isInAppBrowserInstalled(cordovaMetadata) === false) {
                return this._error('InAppBrowser plugin not found');
            }
            this._popup = cordova.InAppBrowser.open(params.url, this.target, this.features);
            if (this._popup) {
                this._exitCallbackEvent = this._exitCallback.bind(this);
                this._errorCallbackEvent = this._errorCallback.bind(this);
                this._loadStartCallbackEvent = this._loadStartCallback.bind(this);
                this._popup.addEventListener('exit', this._exitCallbackEvent, false);
                this._popup.addEventListener('loaderror', this._errorCallbackEvent, false);
                this._popup.addEventListener('loadstart', this._loadStartCallbackEvent, false);
            }
            else {
                this._error('Error opening popup window');
            }
        }
        return this.promise;
    };
    Object.defineProperty(CordovaPopupWindow.prototype, "promise", {
        get: /**
         * @return {?}
         */
        function () {
            return this._promise;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} message
     * @return {?}
     */
    CordovaPopupWindow.prototype._errorCallback = /**
     * @param {?} message
     * @return {?}
     */
    function (message) {
        console.error(message);
        if (!message.url || message.url.indexOf(this.redirect_uri) === -1) {
            this._error(message);
        }
    };
    /**
     * @param {?} event
     * @return {?}
     */
    CordovaPopupWindow.prototype._loadStartCallback = /**
     * @param {?} event
     * @return {?}
     */
    function (event) {
        if (event.url.indexOf(this.redirect_uri) === 0) {
            this._success({ urlFragment: event.url });
        }
    };
    Object.defineProperty(CordovaPopupWindow.prototype, "exited", {
        get: /**
         * @return {?}
         */
        function () {
            if (!this._popup) {
                return this._exited;
            }
            else {
                return false;
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} message
     * @return {?}
     */
    CordovaPopupWindow.prototype._exitCallback = /**
     * @param {?} message
     * @return {?}
     */
    function (message) {
        console.error(message);
        if (message.type === 'exit') {
            this._exited = true;
        }
        this._error(message);
    };
    /**
     * @param {?} data
     * @return {?}
     */
    CordovaPopupWindow.prototype._success = /**
     * @param {?} data
     * @return {?}
     */
    function (data) {
        this._cleanup();
        this._resolve(data);
    };
    /**
     * @param {?} message
     * @return {?}
     */
    CordovaPopupWindow.prototype._error = /**
     * @param {?} message
     * @return {?}
     */
    function (message) {
        this._cleanup();
        this._reject(new Error(message));
    };
    /**
     * @return {?}
     */
    CordovaPopupWindow.prototype.close = /**
     * @return {?}
     */
    function () {
        this._cleanup();
    };
    /**
     * @return {?}
     */
    CordovaPopupWindow.prototype._cleanup = /**
     * @return {?}
     */
    function () {
        if (this._popup) {
            this._popup.removeEventListener('exit', this._exitCallbackEvent, false);
            this._popup.removeEventListener('loadstart', this._loadStartCallbackEvent, false);
            this._popup.close();
        }
        this._popup = null;
    };
    return CordovaPopupWindow;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var OAUTH_ANGULAR_CONFIG = new InjectionToken('OAuthAngularConfig');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Responsável por guardar o usuário e tenant da sessão
 */
var OAuthAngularSessionService = /** @class */ (function () {
    function OAuthAngularSessionService() {
    }
    Object.defineProperty(OAuthAngularSessionService.prototype, "storageName", {
        get: /**
         * @return {?}
         */
        function () {
            /** @type {?} */
            var storageUniqueName = this.tenant.shortNameTenant;
            if (this.user) {
                storageUniqueName += this.user.userShortName;
            }
            return storageUniqueName;
        },
        enumerable: true,
        configurable: true
    });
    OAuthAngularSessionService.decorators = [
        { type: Injectable }
    ];
    return OAuthAngularSessionService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var OAuthAngularStorageSessionService = /** @class */ (function (_super) {
    __extends(OAuthAngularStorageSessionService, _super);
    function OAuthAngularStorageSessionService(session) {
        var _this = _super.call(this) || this;
        _this.session = session;
        return _this;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    OAuthAngularStorageSessionService.prototype.getItem = /**
     * @param {?} key
     * @return {?}
     */
    function (key) {
        return window.localStorage.getItem(this.getKey(key));
    };
    /**
     * @param {?} key
     * @return {?}
     */
    OAuthAngularStorageSessionService.prototype.removeItem = /**
     * @param {?} key
     * @return {?}
     */
    function (key) {
        window.localStorage.removeItem(this.getKey(key));
    };
    /**
     * @param {?} key
     * @param {?} data
     * @return {?}
     */
    OAuthAngularStorageSessionService.prototype.setItem = /**
     * @param {?} key
     * @param {?} data
     * @return {?}
     */
    function (key, data) {
        window.localStorage.setItem(this.getKey(key), data);
    };
    /**
     * @param {?} key
     * @return {?}
     */
    OAuthAngularStorageSessionService.prototype.getKey = /**
     * @param {?} key
     * @return {?}
     */
    function (key) {
        return this.session.tenant
            ? this.session.tenant.shortNameTenant + '_' + key
            : key;
    };
    OAuthAngularStorageSessionService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    OAuthAngularStorageSessionService.ctorParameters = function () { return [
        { type: OAuthAngularSessionService }
    ]; };
    return OAuthAngularStorageSessionService;
}(OAuthStorage));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
var  /**
 * @abstract
 */
TenantService = /** @class */ (function () {
    function TenantService() {
    }
    return TenantService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var jwtDecode = jwtDecodeLib;
// tslint:disable: no-string-literal
var UserInfoRac = /** @class */ (function () {
    function UserInfoRac(userId, userShortName, userFullName, tenantId, tenantShortName, tenantFullName, roles, token) {
        this.userId = userId;
        this.userShortName = userShortName;
        this.userFullName = userFullName;
        this.tenantId = tenantId;
        this.tenantShortName = tenantShortName;
        this.tenantFullName = tenantFullName;
        this.roles = roles;
        this.token = token;
    }
    /**
     * @param {?} jwt
     * @return {?}
     */
    UserInfoRac.ofJwt = /**
     * @param {?} jwt
     * @return {?}
     */
    function (jwt) {
        /** @type {?} */
        var jsonToken;
        try {
            jsonToken = jwtDecode(jwt);
        }
        catch (error) {
            console.error(error);
            throw new CriticalError('Não foi possível autorizar o token por erro de decodificação');
        }
        try {
            /** @type {?} */
            var roles = [];
            if (jsonToken['role']) {
                if (!Array.isArray(jsonToken['role'])) {
                    jsonToken['role'] = [jsonToken['role']];
                }
                roles = jsonToken['role'];
            }
            return new UserInfoRac(jsonToken['sub'], jsonToken['name'][0], jsonToken[UserInfoRac.USER_FULL_NAME_CLAIM], jsonToken[UserInfoRac.TENANT_ID_CLAIM], jsonToken[UserInfoRac.TENANT_NAME_CLAIM], jsonToken[UserInfoRac.TENANT_FULL_NAME_CLAIM], roles, jwt);
        }
        catch (error) {
            console.error(error);
            throw new CriticalError('Não foi possível autorizar o token por erro de conversão');
        }
    };
    UserInfoRac.USER_FULL_NAME_CLAIM = 'http://www.tnf.com/identity/claims/userFullname';
    UserInfoRac.TENANT_ID_CLAIM = 'http://www.tnf.com/identity/claims/tenantId';
    UserInfoRac.TENANT_NAME_CLAIM = 'http://www.tnf.com/identity/claims/tenantName';
    UserInfoRac.TENANT_FULL_NAME_CLAIM = 'http://www.tnf.com/identity/claims/tenantFullName';
    return UserInfoRac;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// tslint:disable: no-string-literal
var OAuthAngularService = /** @class */ (function () {
    function OAuthAngularService(oAuthAngularConfig, loggingService, network, oauth, session, tenantPersistence) {
        this.oAuthAngularConfig = oAuthAngularConfig;
        this.loggingService = loggingService;
        this.network = network;
        this.oauth = oauth;
        this.session = session;
        this.tenantPersistence = tenantPersistence;
        this.isBackButton = false;
        this.tokenExpiredEvent = new EventEmitter();
        this.authorizedEvent = new EventEmitter();
        this.unauthorizedEvent = new EventEmitter();
        oauth.tokenValidationHandler = new JwksValidationHandler();
    }
    /**
     * @return {?}
     */
    OAuthAngularService.prototype.authorize = /**
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var oAuthAngularConfig, error_1, authorized;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.session.tenant || !this.session.tenant.shortNameTenant || this.session.tenant.shortNameTenant === '') {
                            return [2 /*return*/, false];
                        }
                        oAuthAngularConfig = new AuthConfig(this.oAuthAngularConfig);
                        oAuthAngularConfig.issuer = oAuthAngularConfig.issuer.replace('{tenant}', this.session.tenant.shortNameTenant);
                        if (!!this.getAccessToken()) return [3 /*break*/, 2];
                        this.oauth.configure(oAuthAngularConfig);
                        return [4 /*yield*/, this.oauth.loadDiscoveryDocumentAndTryLogin()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        if (!!this.getAccessToken()) return [3 /*break*/, 7];
                        _a.label = 3;
                    case 3:
                        _a.trys.push([3, 5, , 6]);
                        return [4 /*yield*/, this.loginFlow(oAuthAngularConfig)];
                    case 4:
                        _a.sent();
                        return [3 /*break*/, 6];
                    case 5:
                        error_1 = _a.sent();
                        return [3 /*break*/, 6];
                    case 6: return [3 /*break*/, 9];
                    case 7: return [4 /*yield*/, this.gotTokenFlow(oAuthAngularConfig)];
                    case 8:
                        _a.sent();
                        _a.label = 9;
                    case 9:
                        authorized = this.getAccessToken() && this.getAccessToken().length > 0;
                        return [2 /*return*/, authorized];
                }
            });
        });
    };
    /**
     * @return {?}
     */
    OAuthAngularService.prototype.logoutFlow = /**
     * @return {?}
     */
    function () {
        this.teardownAutomaticSilentRefresh();
        this.oauth.logOut(true);
        /** @type {?} */
        var browser = new CordovaPopupWindow({
            startUrl: 'https://localhost/oidc',
            popupWindowFeatures: 'hidden=yes,clearcache=yes,clearsessioncache=yes'
        });
        return browser.navigate({
            url: 'https://localhost/oidc'
        }).then((/**
         * @return {?}
         */
        function () { })).catch(console.error);
    };
    /**
     * @private
     * @return {?}
     */
    OAuthAngularService.prototype.getAccessToken = /**
     * @private
     * @return {?}
     */
    function () {
        if (this.isExpired()) {
            return '';
        }
        return this.oauth.getAccessToken();
    };
    /**
     * @private
     * @return {?}
     */
    OAuthAngularService.prototype.getUser = /**
     * @private
     * @return {?}
     */
    function () {
        if (!this.getAccessToken()) {
            return this.session.user;
        }
        return UserInfoRac.ofJwt(this.getAccessToken());
    };
    /**
     * @private
     * @return {?}
     */
    OAuthAngularService.prototype.isExpired = /**
     * @private
     * @return {?}
     */
    function () {
        return (!this.oauth.getAccessTokenExpiration() ||
            this.oauth.getAccessTokenExpiration() < new Date().getTime() + 1000); // Folga para considerar expirado com um segundo de antecedência
    };
    /**
     * @private
     * @param {?} oAuthAngularConfig
     * @return {?}
     */
    OAuthAngularService.prototype.silentRefresh = /**
     * @private
     * @param {?} oAuthAngularConfig
     * @return {?}
     */
    function (oAuthAngularConfig) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.oauth.configure(oAuthAngularConfig);
                        return [4 /*yield*/, this.oauth.loadDiscoveryDocumentAndTryLogin()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/, this.loginFlow(oAuthAngularConfig, this.oauth['createLoginUrl'](null, null, oAuthAngularConfig.silentRefreshRedirectUri || oAuthAngularConfig.redirectUri, true), 'yes')];
                }
            });
        });
    };
    /**
     * @private
     * @param {?} authConfig
     * @return {?}
     */
    OAuthAngularService.prototype.setupAutomaticSilentRefresh = /**
     * @private
     * @param {?} authConfig
     * @return {?}
     */
    function (authConfig) {
        var _this = this;
        if (!this.silentRenew) {
            this.silentRenew = this.tokenExpiredEvent.subscribe((/**
             * @return {?}
             */
            function () {
                _this.silentRefresh(authConfig).catch((/**
                 * @return {?}
                 */
                function () {
                    timer(300000, 300000)
                        .pipe(takeUntil(_this.oauth.events.pipe(filter((/**
                     * @param {?} x
                     * @return {?}
                     */
                    function (x) {
                        return x.type === 'token_refreshed' ||
                            x.type === 'token_received' ||
                            x.type === 'silently_refreshed';
                    })))), takeWhile((/**
                     * @return {?}
                     */
                    function () { return _this.silentRenew !== undefined; })))
                        .subscribe((/**
                     * @return {?}
                     */
                    function () {
                        _this.silentRefresh(authConfig).catch((/**
                         * @return {?}
                         */
                        function () { }));
                    }));
                }));
            }));
        }
    };
    /**
     * @return {?}
     */
    OAuthAngularService.prototype.teardownAutomaticSilentRefresh = /**
     * @return {?}
     */
    function () {
        if (this.silentRenew) {
            this.silentRenew.unsubscribe();
            this.silentRenew = undefined;
        }
    };
    /**
     * @private
     * @param {?} user
     * @return {?}
     */
    OAuthAngularService.prototype.setCurrentTenantFromUser = /**
     * @private
     * @param {?} user
     * @return {?}
     */
    function (user) {
        return __awaiter(this, void 0, void 0, function () {
            var tenant, tenantAdded;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        tenant = {
                            id: user.tenantId,
                            name: user.tenantFullName,
                            shortNameTenant: user.tenantShortName
                        };
                        this.session.tenant = tenant;
                        return [4 /*yield*/, this.tenantPersistence.addTenant(tenant)];
                    case 1:
                        tenantAdded = _a.sent();
                        return [4 /*yield*/, this.tenantPersistence.setCurrentTenant(tenantAdded)];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @private
     * @param {?} auth
     * @param {?=} urlAuth
     * @param {?=} hidden
     * @return {?}
     */
    OAuthAngularService.prototype.loginFlow = /**
     * @private
     * @param {?} auth
     * @param {?=} urlAuth
     * @param {?=} hidden
     * @return {?}
     */
    function (auth, urlAuth, hidden) {
        if (urlAuth === void 0) { urlAuth = this.oauth['createLoginUrl'](); }
        if (hidden === void 0) { hidden = 'no'; }
        return __awaiter(this, void 0, void 0, function () {
            var url, logger, browser, urlFragment, e_1, error_2, authorized;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.isBackButton = false;
                        return [4 /*yield*/, urlAuth];
                    case 1:
                        url = _a.sent();
                        logger = this.loggingService.getLogger('OAuthAngularService');
                        browser = new CordovaPopupWindow({
                            startUrl: auth.redirectUri,
                            popupWindowFeatures: hidden === 'yes' ? 'hidden=yes' : undefined
                        });
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 4, , 5]);
                        return [4 /*yield*/, browser.navigate({ url: url })];
                    case 3:
                        urlFragment = _a.sent();
                        return [3 /*break*/, 5];
                    case 4:
                        e_1 = _a.sent();
                        if (!browser.exited) {
                            logger.error(this.session.storageName, 'loginFlow', e_1);
                            throw e_1;
                        }
                        return [3 /*break*/, 5];
                    case 5:
                        this.isBackButton = browser.exited;
                        _a.label = 6;
                    case 6:
                        _a.trys.push([6, 8, , 9]);
                        return [4 /*yield*/, this.oauth.tryLogin({
                                customHashFragment: '#' + urlFragment.urlFragment.split('#')[1]
                            })];
                    case 7:
                        _a.sent();
                        return [3 /*break*/, 9];
                    case 8:
                        error_2 = _a.sent();
                        console.error(error_2);
                        return [3 /*break*/, 9];
                    case 9:
                        if (!this.getAccessToken()) return [3 /*break*/, 11];
                        return [4 /*yield*/, this.gotTokenFlow(auth)];
                    case 10:
                        _a.sent();
                        authorized = this.getAccessToken() && this.getAccessToken().length > 0;
                        if (authorized) {
                            this.authorizedEvent.emit();
                        }
                        else {
                            this.unauthorizedEvent.emit();
                        }
                        _a.label = 11;
                    case 11: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @param {?} auth
     * @return {?}
     */
    OAuthAngularService.prototype.gotTokenFlow = /**
     * @param {?} auth
     * @return {?}
     */
    function (auth) {
        return __awaiter(this, void 0, void 0, function () {
            var access;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        of({}).pipe(delay((this.oauth.getAccessTokenExpiration() - new Date().getTime()) * 0.95))
                            .subscribe((/**
                         * @return {?}
                         */
                        function () {
                            _this.tokenExpiredEvent.emit();
                        }));
                        access = this.getAccessToken() && this.getAccessToken().length > 0;
                        if (!access) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.setCurrentTenantFromUser(this.getUser())];
                    case 1:
                        _a.sent();
                        this.session.user = this.getUser();
                        this.setupAutomaticSilentRefresh(auth);
                        _a.label = 2;
                    case 2:
                        if (!this.networkConnect) {
                            this.networkConnect = this.network.onConnect().pipe(filter((/**
                             * @return {?}
                             */
                            function () { return _this.silentRenew !== undefined; }))).subscribe((/**
                             * @return {?}
                             */
                            function () {
                                _this.silentRefresh(auth).catch((/**
                                 * @return {?}
                                 */
                                function () { }));
                            }));
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    OAuthAngularService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    OAuthAngularService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [OAUTH_ANGULAR_CONFIG,] }] },
        { type: LoggingService },
        { type: Network },
        { type: OAuthService },
        { type: OAuthAngularSessionService },
        { type: TenantService }
    ]; };
    return OAuthAngularService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Implementação de guard com uso do serviço de autenticação padrão
 */
var OAuthAngularGuard = /** @class */ (function () {
    function OAuthAngularGuard(authService, router) {
        this.authService = authService;
        this.router = router;
    }
    /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     */
    /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     * @return {?}
     */
    OAuthAngularGuard.prototype.canActivate = /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var authorized;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.authService.authorize()];
                    case 1:
                        authorized = _a.sent();
                        if (!authorized && this.authService.oAuthAngularConfig.unathorizedRedirectRoute) {
                            return [2 /*return*/, this.router.parseUrl("/" + this.authService.oAuthAngularConfig.unathorizedRedirectRoute)];
                        }
                        else {
                            return [2 /*return*/, authorized];
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    OAuthAngularGuard.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    OAuthAngularGuard.ctorParameters = function () { return [
        { type: OAuthAngularService },
        { type: Router }
    ]; };
    return OAuthAngularGuard;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var OAuthAngularInterceptor = /** @class */ (function () {
    function OAuthAngularInterceptor(session) {
        this.session = session;
    }
    /**
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    OAuthAngularInterceptor.prototype.intercept = /**
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    function (req, next) {
        if (this.session.tenant && this.session.user) {
            return next.handle(req.clone({
                url: req.url.replace('{tenant}', this.session.tenant.shortNameTenant),
                setHeaders: {
                    Authorization: 'Bearer ' + this.session.user.token
                }
            }));
        }
        else {
            return next.handle(req);
        }
    };
    OAuthAngularInterceptor.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    OAuthAngularInterceptor.ctorParameters = function () { return [
        { type: OAuthAngularSessionService }
    ]; };
    return OAuthAngularInterceptor;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var WithoutTenantStorageService = /** @class */ (function (_super) {
    __extends(WithoutTenantStorageService, _super);
    function WithoutTenantStorageService() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @return {?}
     */
    WithoutTenantStorageService.prototype.getCurrentTenant = /**
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, Promise.resolve(null)];
            });
        });
    };
    /**
     * @param {?} currentTenant
     * @return {?}
     */
    WithoutTenantStorageService.prototype.setCurrentTenant = /**
     * @param {?} currentTenant
     * @return {?}
     */
    function (currentTenant) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, Promise.resolve(null)];
            });
        });
    };
    /**
     * @param {?} tenant
     * @return {?}
     */
    WithoutTenantStorageService.prototype.addTenant = /**
     * @param {?} tenant
     * @return {?}
     */
    function (tenant) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, Promise.resolve(tenant)];
            });
        });
    };
    WithoutTenantStorageService.decorators = [
        { type: Injectable }
    ];
    return WithoutTenantStorageService;
}(TenantService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var OAuthAngularModule = /** @class */ (function () {
    function OAuthAngularModule() {
    }
    /**
     * @param {?} oAuthAngularConfig
     * @return {?}
     */
    OAuthAngularModule.forRoot = /**
     * @param {?} oAuthAngularConfig
     * @return {?}
     */
    function (oAuthAngularConfig) {
        return {
            ngModule: OAuthAngularModule,
            providers: [
                InAppBrowser,
                Network,
                OAuthAngularSessionService,
                OAuthAngularService,
                OAuthAngularGuard,
                {
                    provide: TenantService,
                    useClass: WithoutTenantStorageService
                },
                {
                    provide: OAuthStorage,
                    useClass: OAuthAngularStorageSessionService
                },
                {
                    provide: OAUTH_ANGULAR_CONFIG,
                    useValue: oAuthAngularConfig
                }
            ]
        };
    };
    OAuthAngularModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        OAuthModule.forRoot()
                    ],
                    exports: [
                        OAuthModule
                    ],
                    providers: [
                        {
                            provide: HTTP_INTERCEPTORS,
                            useClass: OAuthAngularInterceptor,
                            multi: true,
                        },
                    ],
                },] }
    ];
    return OAuthAngularModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var MultiTenantService = /** @class */ (function (_super) {
    __extends(MultiTenantService, _super);
    /**
     * Método construtor responsável por inicializar o serviço
     * @param platform Serviço relacionado a plataforma
     * @param storage Serviço relacionado ao storage
     */
    function MultiTenantService(platform, storage) {
        var _this = _super.call(this) || this;
        _this.storage = storage;
        /**
         * @ignore
         * Indica se a plataforma é cordova
         */
        _this.isCordova = false;
        _this.ready = new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        function (resolve) {
            _this.readyFn = resolve;
        }));
        platform.ready().then((/**
         * @return {?}
         */
        function () {
            _this.isCordova = platform.is('cordova');
            if (_this.isCordova) {
                _this.tenantsStorage = new StorageUtil(_this.storage);
                _this.tenantsStorage
                    .config({
                    name: 'Tenants',
                    id: 'shortNameTenant',
                    exclusive: false,
                    lazy: false,
                    initFn: (/**
                     * @return {?}
                     */
                    function () { return []; }),
                })
                    .then((/**
                 * @return {?}
                 */
                function () { }));
                _this.currentTenantStorage = new StorageUtil(_this.storage);
                _this.currentTenantStorage
                    .config({
                    name: 'CurrentTenant',
                    id: 'shortNameTenant',
                    exclusive: false,
                    lazy: true,
                    initFn: (/**
                     * @return {?}
                     */
                    function () { return undefined; }),
                })
                    .then((/**
                 * @return {?}
                 */
                function () { }));
            }
            _this.readyFn();
        }));
        return _this;
    }
    Object.defineProperty(MultiTenantService.prototype, "tenants", {
        get: /**
         * @return {?}
         */
        function () {
            return this.tenantsStorage ? this.tenantsStorage.data : [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MultiTenantService.prototype, "isReady", {
        get: /**
         * @return {?}
         */
        function () {
            return this.ready;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    MultiTenantService.prototype.getCurrentTenant = /**
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var currentTenant, error_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ready];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.currentTenantStorage.read()];
                    case 2:
                        currentTenant = (/** @type {?} */ ((_a.sent())));
                        _a.label = 3;
                    case 3:
                        _a.trys.push([3, 5, , 7]);
                        return [4 /*yield*/, this.tenantsStorage.get(currentTenant.shortNameTenant)];
                    case 4:
                        if (_a.sent()) {
                            return [2 /*return*/, currentTenant];
                        }
                        return [3 /*break*/, 7];
                    case 5:
                        error_1 = _a.sent();
                        this.currentTenantStorage.data = undefined;
                        return [4 /*yield*/, this.currentTenantStorage.updateStorage()];
                    case 6:
                        _a.sent();
                        return [2 /*return*/, undefined];
                    case 7: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @param {?} currentTenant
     * @return {?}
     */
    MultiTenantService.prototype.setCurrentTenant = /**
     * @param {?} currentTenant
     * @return {?}
     */
    function (currentTenant) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ready];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.currentTenantStorage.read()];
                    case 2:
                        _a.sent();
                        if (!this.currentTenantStorage.data) {
                            this.currentTenantStorage.data = currentTenant;
                        }
                        this.currentTenantStorage.data = currentTenant;
                        return [4 /*yield*/, this.currentTenantStorage.updateStorage()];
                    case 3:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @param {?} tenant
     * @return {?}
     */
    MultiTenantService.prototype.addTenant = /**
     * @param {?} tenant
     * @return {?}
     */
    function (tenant) {
        return __awaiter(this, void 0, void 0, function () {
            var tenants;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ready];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.tenantsStorage.read()];
                    case 2:
                        tenants = (/** @type {?} */ ((_a.sent())));
                        // Verificação de duplicidade de tenant
                        if (tenants && tenants.length > 0) {
                            tenants.forEach((/**
                             * @param {?} tenantFromStorage
                             * @param {?} index
                             * @return {?}
                             */
                            function (tenantFromStorage, index) {
                                if (tenantFromStorage.shortNameTenant === tenant.shortNameTenant) {
                                    tenants.splice(index, 1);
                                }
                            }));
                        }
                        this.tenantsStorage.data = tenants;
                        this.tenantsStorage.data.push(tenant);
                        this.sortTenantsByShortName();
                        return [4 /*yield*/, this.tenantsStorage.updateStorage()];
                    case 3:
                        _a.sent();
                        return [2 /*return*/, tenant];
                }
            });
        });
    };
    /**
     * @param {?} tenant
     * @return {?}
     */
    MultiTenantService.prototype.deleteTenant = /**
     * @param {?} tenant
     * @return {?}
     */
    function (tenant) {
        return __awaiter(this, void 0, void 0, function () {
            var error_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ready];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 5, , 6]);
                        return [4 /*yield*/, this.tenantsStorage.delete(tenant.shortNameTenant)];
                    case 3:
                        _a.sent();
                        return [4 /*yield*/, this.tenantsStorage.read()];
                    case 4:
                        _a.sent();
                        return [3 /*break*/, 6];
                    case 5:
                        error_2 = _a.sent();
                        console.error(error_2);
                        return [3 /*break*/, 6];
                    case 6: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @private
     * @return {?}
     */
    MultiTenantService.prototype.sortTenantsByShortName = /**
     * @private
     * @return {?}
     */
    function () {
        /** @type {?} */
        var sortBy = (/**
         * @param {?} fn
         * @return {?}
         */
        function (fn) { return (/**
         * @param {?} a
         * @param {?} b
         * @return {?}
         */
        function (a, b) { return -(fn(a) < fn(b)) || +(fn(a) > fn(b)); }); });
        /** @type {?} */
        var getShortName = (/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return o.shortNameTenant; });
        /** @type {?} */
        var sortByShortName = sortBy(getShortName);
        this.tenantsStorage.data.sort(sortByShortName);
    };
    MultiTenantService.SHORT_NAME_TENANT_FIELD = 'tenantId';
    MultiTenantService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    MultiTenantService.ctorParameters = function () { return [
        { type: Platform },
        { type: Storage }
    ]; };
    return MultiTenantService;
}(TenantService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SingleTenantService = /** @class */ (function (_super) {
    __extends(SingleTenantService, _super);
    /**
     * Método construtor responsável por inicializar o serviço
     * @param platform Serviço relacionado a plataforma
     * @param storage Serviço relacionado ao storage
     */
    function SingleTenantService(platform, storage) {
        var _this = _super.call(this) || this;
        _this.storage = storage;
        /**
         * @ignore
         * Indica se a plataforma é cordova
         */
        _this.isCordova = false;
        _this.ready = new Promise((/**
         * @param {?} resolve
         * @return {?}
         */
        function (resolve) {
            _this.readyFn = resolve;
        }));
        platform.ready().then((/**
         * @return {?}
         */
        function () {
            _this.isCordova = platform.is('cordova');
            if (_this.isCordova) {
                _this.currentTenantStorage = new StorageUtil(_this.storage);
                _this.currentTenantStorage
                    .config({
                    name: 'CurrentTenant',
                    id: 'shortNameTenant',
                    exclusive: false,
                    lazy: true,
                    initFn: (/**
                     * @return {?}
                     */
                    function () { return undefined; }),
                })
                    .then((/**
                 * @return {?}
                 */
                function () { }));
            }
            _this.readyFn();
        }));
        return _this;
    }
    Object.defineProperty(SingleTenantService.prototype, "isReady", {
        get: /**
         * @return {?}
         */
        function () {
            return this.ready;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    SingleTenantService.prototype.getCurrentTenant = /**
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var currentTenant;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ready];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.currentTenantStorage.read()];
                    case 2:
                        currentTenant = (/** @type {?} */ ((_a.sent())));
                        return [2 /*return*/, currentTenant];
                }
            });
        });
    };
    /**
     * @param {?} currentTenant
     * @return {?}
     */
    SingleTenantService.prototype.setCurrentTenant = /**
     * @param {?} currentTenant
     * @return {?}
     */
    function (currentTenant) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.ready];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.currentTenantStorage.read()];
                    case 2:
                        _a.sent();
                        if (!this.currentTenantStorage.data) {
                            this.currentTenantStorage.data = currentTenant;
                        }
                        this.currentTenantStorage.data = currentTenant;
                        return [4 /*yield*/, this.currentTenantStorage.updateStorage()];
                    case 3:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @param {?} tenant
     * @return {?}
     */
    SingleTenantService.prototype.addTenant = /**
     * @param {?} tenant
     * @return {?}
     */
    function (tenant) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this.setCurrentTenant(tenant);
                return [2 /*return*/, tenant];
            });
        });
    };
    SingleTenantService.SHORT_NAME_TENANT_FIELD = 'tenantId';
    SingleTenantService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    SingleTenantService.ctorParameters = function () { return [
        { type: Platform },
        { type: Storage }
    ]; };
    return SingleTenantService;
}(TenantService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { OAUTH_ANGULAR_CONFIG, OAuthAngularSessionService, OAuthAngularStorageSessionService, OAuthAngularGuard, OAuthAngularInterceptor, OAuthAngularModule, OAuthAngularService, CordovaPopupWindow, MultiTenantService, SingleTenantService, TenantService, WithoutTenantStorageService, UserInfoRac };

//# sourceMappingURL=totvs-log-mobile-foundation-src-oauth-angular.js.map