import { TranslateService, TranslateModule, TranslateLoader } from '@ngx-translate/core';
import { TranslateHttpLoader } from '@ngx-translate/http-loader';
import { HttpClient, HTTP_INTERCEPTORS } from '@angular/common/http';
import { CommonModule, DatePipe } from '@angular/common';
import { __extends, __values, __awaiter, __generator } from 'tslib';
import { ReplaySubject } from 'rxjs';
import { map, take } from 'rxjs/operators';
import { Injectable, Inject, InjectionToken, NgModule, Pipe, APP_INITIALIZER, Injector } from '@angular/core';
import { AlertController, ToastController, LoadingController } from '@ionic/angular';
import { CriticalError, I18nBaseService, AbstractShowMessage, ShowMessageLinkActionType, ShowMessageType, MessageDisplayerService, ApiDateTimeService, LoadingDefault, HttpInterceptorBaseService, MessageUtils, DefaultDateViewConverterService, DateViewConverter, DateTimeModule, TimeViewConverter, DefaultTimeViewConverterService } from 'totvs-log-base-foundation';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço utilizado para carregar as literais
 */
var IntlLiteralsLoaderService = /** @class */ (function () {
    /**
     * Método construtor da classe
     * translate
     */
    function IntlLiteralsLoaderService(translate) {
        this.translate = translate;
        /**
         * Responsável por receber as configurações do serviço de tradução para carregar as literais
         */
        this.mobileOptions = { language: 'pt-br', url: '' };
    }
    /**
     * Método responsável por setar as opções e retornar a literal atualizada
     * options
     */
    /**
     * Método responsável por setar as opções e retornar a literal atualizada
     * options
     * @param {?} options
     * @return {?}
     */
    IntlLiteralsLoaderService.prototype.updateOptions = /**
     * Método responsável por setar as opções e retornar a literal atualizada
     * options
     * @param {?} options
     * @return {?}
     */
    function (options) {
        try {
            Object.assign(this.mobileOptions, options);
            return this.load();
        }
        catch (error) {
            throw new CriticalError(error);
        }
    };
    /**
     * Método responsável por setar o carregamento e retornar a literal atualizada
     */
    /**
     * Método responsável por setar o carregamento e retornar a literal atualizada
     * @return {?}
     */
    IntlLiteralsLoaderService.prototype.load = /**
     * Método responsável por setar o carregamento e retornar a literal atualizada
     * @return {?}
     */
    function () {
        return this.translate.getTranslation(this.mobileOptions.language)
            .pipe(map((/**
         * @param {?} res
         * @return {?}
         */
        function (res) { return res; })));
    };
    IntlLiteralsLoaderService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    IntlLiteralsLoaderService.ctorParameters = function () { return [
        { type: TranslateService }
    ]; };
    return IntlLiteralsLoaderService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Token de configuração da url de internacionalização
 * @type {?}
 */
var INTL_CONFIG = new InjectionToken('Configurações da internacionalização');
/**
 * Serviço de internacionalização da aplicação
 */
var IntlService = /** @class */ (function (_super) {
    __extends(IntlService, _super);
    /**
     * Método construtor que inicializa a classe
     * translate Serviço de internacionalização
     */
    function IntlService(config, intlLiteralsLoader) {
        var _this = _super.call(this, intlLiteralsLoader) || this;
        /**
         * Atributo de opções de internacionalização
         */
        _this.options = { language: 'pt-br', url: '' };
        /** @type {?} */
        var matchedNavigatorAppLanguage;
        if (config.supportedLanguages) {
            matchedNavigatorAppLanguage = config.supportedLanguages.find((/**
             * @param {?} appSupportedLanguage
             * @return {?}
             */
            function (appSupportedLanguage) {
                return appSupportedLanguage.language === navigator.language;
            }));
        }
        if (!matchedNavigatorAppLanguage) {
            matchedNavigatorAppLanguage = { language: 'pt-br' };
        }
        _this.options.language = matchedNavigatorAppLanguage.language.toLowerCase();
        return _this;
    }
    IntlService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    IntlService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [INTL_CONFIG,] }] },
        { type: IntlLiteralsLoaderService }
    ]; };
    return IntlService;
}(I18nBaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável pela apresentação de mensagens
 */
var ShowMessageService = /** @class */ (function (_super) {
    __extends(ShowMessageService, _super);
    /**
     * Método construtor que inicializa a classe
     * toastCtrl Serviço de TOAST
     * alertCtrl Serviço de Alerta
     * i18n Serviço de internacionalização
     */
    function ShowMessageService(toastCtrl, alertCtrl) {
        var _this = _super.call(this) || this;
        _this.toastCtrl = toastCtrl;
        _this.alertCtrl = alertCtrl;
        return _this;
    }
    /**
     * Método responsável por apresentar uma mensagem
     */
    /**
     * Método responsável por apresentar uma mensagem
     * @param {?} showMessageOptions
     * @return {?}
     */
    ShowMessageService.prototype.displayMessage = /**
     * Método responsável por apresentar uma mensagem
     * @param {?} showMessageOptions
     * @return {?}
     */
    function (showMessageOptions) {
        return __awaiter(this, void 0, void 0, function () {
            var _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = showMessageOptions.messageType;
                        switch (_a) {
                            case ShowMessageType.NotificationSuccess: return [3 /*break*/, 1];
                            case ShowMessageType.NotificationError: return [3 /*break*/, 1];
                            case ShowMessageType.NotificationWarning: return [3 /*break*/, 1];
                            case ShowMessageType.NotificationInformation: return [3 /*break*/, 1];
                            case ShowMessageType.DialogAlert: return [3 /*break*/, 3];
                            case ShowMessageType.DialogConfirmation: return [3 /*break*/, 3];
                        }
                        return [3 /*break*/, 5];
                    case 1: return [4 /*yield*/, this.showNotification(showMessageOptions)];
                    case 2:
                        _b.sent();
                        return [3 /*break*/, 6];
                    case 3: return [4 /*yield*/, this.showDialog(showMessageOptions)];
                    case 4:
                        _b.sent();
                        return [3 /*break*/, 6];
                    case 5: throw new Error('Tipo de mensagem inválido');
                    case 6: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Método responsável por apresentar uma mensagem de notificação
     */
    /**
     * Método responsável por apresentar uma mensagem de notificação
     * @private
     * @param {?} showMessageOptions
     * @return {?}
     */
    ShowMessageService.prototype.showNotification = /**
     * Método responsável por apresentar uma mensagem de notificação
     * @private
     * @param {?} showMessageOptions
     * @return {?}
     */
    function (showMessageOptions) {
        return __awaiter(this, void 0, void 0, function () {
            var toast;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.toastCtrl.create({
                            message: showMessageOptions.messageText,
                            color: this.getColorByMessageType(showMessageOptions.messageType),
                            duration: showMessageOptions.messageLinkActionType ===
                                ShowMessageLinkActionType.No
                                ? 3000
                                : 10000,
                            position: 'bottom',
                            showCloseButton: showMessageOptions.messageLinkActionType !==
                                ShowMessageLinkActionType.No,
                            closeButtonText: showMessageOptions.messageLinkLabel
                        })];
                    case 1:
                        toast = _a.sent();
                        toast.onDidDismiss().then((/**
                         * @return {?}
                         */
                        function () {
                            if (showMessageOptions.messageLinkActionType ===
                                ShowMessageLinkActionType.LinkNewTab) {
                                _this.openLink(showMessageOptions.messageLinkAction);
                            }
                            else if (showMessageOptions.messageLinkActionType ===
                                ShowMessageLinkActionType.Method &&
                                showMessageOptions.messageLinkAction) {
                                showMessageOptions.messageLinkAction();
                            }
                        }));
                        return [4 /*yield*/, toast.present()];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Método responsável por apresentar uma mensagem de diálogo
     */
    /**
     * Método responsável por apresentar uma mensagem de diálogo
     * @private
     * @param {?} showMessageOptions
     * @return {?}
     */
    ShowMessageService.prototype.showDialog = /**
     * Método responsável por apresentar uma mensagem de diálogo
     * @private
     * @param {?} showMessageOptions
     * @return {?}
     */
    function (showMessageOptions) {
        return __awaiter(this, void 0, void 0, function () {
            var buttons, alert;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        buttons = [];
                        if (showMessageOptions.messageCancelLabel &&
                            showMessageOptions.messageCancelLabel.trim() !== '' &&
                            showMessageOptions.messageType === ShowMessageType.DialogConfirmation) {
                            buttons.push({
                                text: showMessageOptions.messageCancelLabel,
                                handler: (/**
                                 * @return {?}
                                 */
                                function () {
                                    alert.dismiss(false);
                                    if (showMessageOptions.messageCancelAction) {
                                        showMessageOptions.messageCancelAction();
                                    }
                                    return false;
                                })
                            });
                        }
                        if (showMessageOptions.messageConfirmLabel &&
                            showMessageOptions.messageConfirmLabel.trim() !== '') {
                            buttons.push({
                                text: showMessageOptions.messageConfirmLabel,
                                handler: (/**
                                 * @return {?}
                                 */
                                function () {
                                    alert.dismiss(true);
                                    if (showMessageOptions.messageConfirmAction) {
                                        showMessageOptions.messageConfirmAction();
                                    }
                                    return true;
                                })
                            });
                        }
                        return [4 /*yield*/, this.alertCtrl.create({
                                message: showMessageOptions.messageDetails,
                                header: showMessageOptions.messageTitle,
                                subHeader: showMessageOptions.messageText,
                                buttons: buttons
                            })];
                    case 1:
                        alert = _a.sent();
                        return [4 /*yield*/, alert.present()];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Método responsável pela abertura de um link
     */
    /**
     * Método responsável pela abertura de um link
     * @private
     * @param {?} link
     * @return {?}
     */
    ShowMessageService.prototype.openLink = /**
     * Método responsável pela abertura de um link
     * @private
     * @param {?} link
     * @return {?}
     */
    function (link) {
        link = link.indexOf('http://') === -1 ? "http://" + link : link;
        window.open(link, '_blank');
    };
    /**
     * @private
     * @param {?} type
     * @return {?}
     */
    ShowMessageService.prototype.getColorByMessageType = /**
     * @private
     * @param {?} type
     * @return {?}
     */
    function (type) {
        switch (type) {
            case ShowMessageType.NotificationSuccess:
                return 'success';
            case ShowMessageType.NotificationError:
                return 'danger';
            case ShowMessageType.NotificationWarning:
                return 'warning';
            default:
                return undefined;
        }
    };
    ShowMessageService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    ShowMessageService.ctorParameters = function () { return [
        { type: ToastController },
        { type: AlertController }
    ]; };
    return ShowMessageService;
}(AbstractShowMessage));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ShowMessageModule = /** @class */ (function () {
    function ShowMessageModule() {
    }
    ShowMessageModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [],
                    exports: [],
                    providers: [
                        ShowMessageService,
                        MessageDisplayerService,
                        {
                            provide: AbstractShowMessage,
                            useClass: ShowMessageService
                        }
                    ]
                },] }
    ];
    return ShowMessageModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Pipe de internacionalização da aplicação
 */
var I18NPipe = /** @class */ (function () {
    /**
     * Método construtor que inicializa a classe
     * i18nService Serviço de internacionalização
     */
    function I18NPipe(i18nService) {
        this.i18nService = i18nService;
    }
    /**
     * Método responsável pela transformação da string
     * query
     * data
     */
    /**
     * Método responsável pela transformação da string
     * query
     * data
     * @param {?} query
     * @param {?} data
     * @return {?}
     */
    I18NPipe.prototype.transform = /**
     * Método responsável pela transformação da string
     * query
     * data
     * @param {?} query
     * @param {?} data
     * @return {?}
     */
    function (query, data) {
        if (!query || query.length === 0) {
            return '';
        }
        /** @type {?} */
        var ret = this.cached(query, data);
        if (ret) {
            return ret;
        }
        if (!data) {
            data = [''];
        }
        else if (!Array.isArray(data)) {
            data = [data];
        }
        return this.i18nService.format(data, query);
    };
    /**
     * Método responsável por retornar o que está em cache
     * query
     * args
     */
    /**
     * Método responsável por retornar o que está em cache
     * query
     * args
     * @private
     * @param {?} query
     * @param {...?} args
     * @return {?}
     */
    I18NPipe.prototype.cached = /**
     * Método responsável por retornar o que está em cache
     * query
     * args
     * @private
     * @param {?} query
     * @param {...?} args
     * @return {?}
     */
    function (query) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return '';
    };
    I18NPipe.decorators = [
        { type: Pipe, args: [{ name: 'format' },] }
    ];
    /** @nocollapse */
    I18NPipe.ctorParameters = function () { return [
        { type: I18nBaseService }
    ]; };
    return I18NPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var i18nFactory = (/**
 * @param {?} i18n
 * @param {?} config
 * @return {?}
 */
function (i18n, config) {
    return (/**
     * @return {?}
     */
    function () { return new Promise((/**
     * @param {?} resolve
     * @return {?}
     */
    function (resolve) {
        if (config.lazy) {
            resolve(true);
        }
        else {
            i18n.updateOptions({}).subscribe((/**
             * @return {?}
             */
            function () {
                resolve(true);
            }), (/**
             * @param {?} error
             * @return {?}
             */
            function (error) {
                console.error(error);
                resolve(false);
            }));
        }
    })); });
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Função responsável por indicar o diretório que contém os arquivos de tradução
 * http
 * @param {?} http
 * @return {?}
 */
function createTranslateLoader(http) {
    return new TranslateHttpLoader(http, './assets/i18n/', '.json');
}
var ɵ0 = i18nFactory;
/**
 * Módulo responsável pela configuração da internacionalização da aplicação
 */
var IntlModule = /** @class */ (function () {
    function IntlModule() {
    }
    IntlModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        TranslateModule.forRoot({
                            loader: {
                                provide: TranslateLoader,
                                useFactory: createTranslateLoader,
                                deps: [HttpClient],
                            },
                        }),
                    ],
                    declarations: [I18NPipe],
                    exports: [TranslateModule, I18NPipe],
                    providers: [
                        IntlLiteralsLoaderService,
                        {
                            provide: I18nBaseService,
                            useClass: IntlService,
                        },
                        {
                            provide: APP_INITIALIZER,
                            useFactory: ɵ0,
                            deps: [I18nBaseService, INTL_CONFIG],
                            multi: true,
                        },
                    ],
                },] }
    ];
    return IntlModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável por fornecer atributos e métodos que
 * poderão ser utilizados em toda a aplicação
 */
var GlobalService = /** @class */ (function () {
    /**
     * Método construtor que inicializa o serviço
     * i18n Serviço de internacionalização
     * msg Serviço de mensageria para usuário
     * date Serviço de formatação de data
     */
    function GlobalService(i18n, msg, loading, date) {
        this.i18n = i18n;
        this.msg = msg;
        this.loading = loading;
        this.date = date;
    }
    GlobalService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    GlobalService.ctorParameters = function () { return [
        { type: I18nBaseService },
        { type: MessageDisplayerService },
        { type: LoadingDefault },
        { type: ApiDateTimeService }
    ]; };
    return GlobalService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço utilizado para realizar o tratamento das respostas
 */
var DefaultHttpInterceptorService = /** @class */ (function (_super) {
    __extends(DefaultHttpInterceptorService, _super);
    /**
     * Método construtor da classe
     * inj
     */
    function DefaultHttpInterceptorService(inj) {
        var _this = _super.call(this) || this;
        _this.inj = inj;
        return _this;
    }
    /**
     * Método responsável por realizar o tratamento de respostas de sucesso
     * response
     */
    /**
     * Método responsável por realizar o tratamento de respostas de sucesso
     * response
     * @param {?} response
     * @return {?}
     */
    DefaultHttpInterceptorService.prototype.interceptResponse = /**
     * Método responsável por realizar o tratamento de respostas de sucesso
     * response
     * @param {?} response
     * @return {?}
     */
    function (response) {
        var e_1, _a;
        this.msg = this.inj.get(MessageDisplayerService);
        if (response.body && response.body.totvs_messages) {
            if (response.body.totvs_messages instanceof Array) {
                /** @type {?} */
                var messages = response.body.totvs_messages;
                try {
                    for (var messages_1 = __values(messages), messages_1_1 = messages_1.next(); !messages_1_1.done; messages_1_1 = messages_1.next()) {
                        var message = messages_1_1.value;
                        this.showTotvsMessage(message);
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (messages_1_1 && !messages_1_1.done && (_a = messages_1.return)) _a.call(messages_1);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            else {
                this.showTotvsMessage((/** @type {?} */ (response.body.totvs_messages)));
            }
        }
    };
    /**
     * Método responsável por realizar o tratamento de respostas de erro
     * response
     * request
     */
    /**
     * Método responsável por realizar o tratamento de respostas de erro
     * response
     * request
     * @param {?} response
     * @param {?} request
     * @return {?}
     */
    DefaultHttpInterceptorService.prototype.interceptError = /**
     * Método responsável por realizar o tratamento de respostas de erro
     * response
     * request
     * @param {?} response
     * @param {?} request
     * @return {?}
     */
    function (response, request) {
        /** @type {?} */
        var error = (/** @type {?} */ (response.error));
        if (error && error.message && !HttpInterceptorBaseService.isErrorNotificationDisabled(request)) {
            /** @type {?} */
            var title = HttpInterceptorBaseService.titleFromTotvsError(error);
            /** @type {?} */
            var detail = HttpInterceptorBaseService.detailFromTotvsError(error);
            this.showTotvsMessage({
                type: 'error',
                code: title,
                detail: detail
            });
        }
    };
    /**
     * Método responsável por mostrar a mensagem
     * message
     */
    /**
     * Método responsável por mostrar a mensagem
     * message
     * @param {?} message
     * @return {?}
     */
    DefaultHttpInterceptorService.prototype.showTotvsMessage = /**
     * Método responsável por mostrar a mensagem
     * message
     * @param {?} message
     * @return {?}
     */
    function (message) {
        /** @type {?} */
        var messageType = MessageUtils.showMessageTypeFromTotvsMessage(message);
        this.msg.displayMessage({
            messageType: messageType,
            messageText: message.code,
            messageDetails: message.detail
        });
    };
    /**
     * Método responsável por realizar o tratamento da requisição/retorno
     * req
     * next
     */
    /**
     * Método responsável por realizar o tratamento da requisição/retorno
     * req
     * next
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    DefaultHttpInterceptorService.prototype.intercept = /**
     * Método responsável por realizar o tratamento da requisição/retorno
     * req
     * next
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    function (req, next) {
        return _super.prototype.intercept.call(this, req, next);
    };
    DefaultHttpInterceptorService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    DefaultHttpInterceptorService.ctorParameters = function () { return [
        { type: Injector }
    ]; };
    return DefaultHttpInterceptorService;
}(HttpInterceptorBaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var InterceptorModule = /** @class */ (function () {
    function InterceptorModule() {
    }
    InterceptorModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    exports: [],
                    providers: [
                        DefaultHttpInterceptorService,
                        {
                            provide: HTTP_INTERCEPTORS,
                            useClass: DefaultHttpInterceptorService,
                            multi: true
                        }
                    ]
                },] }
    ];
    return InterceptorModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var DateTimeModule$1 = /** @class */ (function () {
    function DateTimeModule$$1() {
    }
    DateTimeModule$$1.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        DateTimeModule
                    ],
                    exports: [],
                    providers: [
                        {
                            provide: DateViewConverter,
                            useClass: DefaultDateViewConverterService
                        },
                        {
                            provide: TimeViewConverter,
                            useClass: DefaultTimeViewConverterService
                        },
                        DatePipe,
                        DefaultDateViewConverterService,
                        DefaultTimeViewConverterService,
                        ApiDateTimeService
                    ]
                },] }
    ];
    return DateTimeModule$$1;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável pela apresentação de loading
 */
var ShowLoadingService = /** @class */ (function (_super) {
    __extends(ShowLoadingService, _super);
    /**
     * Método construtor que inicializa a classe
     * i18n Serviço de internacionalização
     * loadingController Serviço de loading
     */
    function ShowLoadingService(i18n, loadingController) {
        var _this = _super.call(this) || this;
        _this.i18n = i18n;
        _this.loadingController = loadingController;
        _this.loadingIsActiveProperty = new ReplaySubject(1);
        _this.loadingActived = new ReplaySubject(1);
        _this.thfContentTemplate = "\n<div class=\"po-loading po-loading-icon\">\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-1\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-2\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-3\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-4\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-5\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-6\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-7\"></span>\n  <span class=\"po-loading-icon-bar po-loading-icon-bar-8\"></span>\n</div>\n<div class=\"po-font-text-small\">{content}</div>";
        return _this;
    }
    Object.defineProperty(ShowLoadingService.prototype, "loadingIsActive", {
        get: /**
         * @return {?}
         */
        function () {
            return this.loadingIsActiveProperty;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    ShowLoadingService.prototype.showLoading = /**
     * @return {?}
     */
    function () {
        var _this = this;
        if (!this.active) {
            this.active = true;
            this.loadingIsActiveProperty.next(this.active);
            /** @type {?} */
            var content = '';
            if (this.loadingText) {
                content = this.loadingText.text;
            }
            this.loadingController
                .create({
                message: this.thfContentTemplate.replace('{content}', content),
                spinner: null
            })
                .then((/**
             * @param {?} loading
             * @return {?}
             */
            function (loading) {
                _this.loading = loading;
                _this.loading.present().then((/**
                 * @return {?}
                 */
                function () {
                    _this.loadingActived.next();
                }));
            }));
        }
        return this.loadingActived.pipe(take(1));
    };
    /**
     * @return {?}
     */
    ShowLoadingService.prototype.hideLoading = /**
     * @return {?}
     */
    function () {
        var _this = this;
        if (this.active) {
            this.loadingActived.pipe(take(1)).subscribe((/**
             * @return {?}
             */
            function () {
                _this.loadingText = undefined;
                _this.loading.dismiss();
                _this.active = false;
                _this.loadingIsActiveProperty.next(_this.active);
            }));
        }
    };
    /**
     * @param {?} loadingText
     * @return {?}
     */
    ShowLoadingService.prototype.setLoadingText = /**
     * @param {?} loadingText
     * @return {?}
     */
    function (loadingText) {
        var _this = this;
        this.loadingActived.pipe(take(1)).subscribe((/**
         * @return {?}
         */
        function () {
            setTimeout((/**
             * @return {?}
             */
            function () {
                /** @type {?} */
                var baseMessage = _this.i18n.text(loadingText);
                if (_this.loading) {
                    _this.loading.message = _this.thfContentTemplate.replace('{content}', baseMessage.text);
                }
                _this.loadingText = baseMessage;
            }), 33);
        }));
    };
    ShowLoadingService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    ShowLoadingService.ctorParameters = function () { return [
        { type: I18nBaseService },
        { type: LoadingController }
    ]; };
    return ShowLoadingService;
}(LoadingDefault));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ShowLoadingModule = /** @class */ (function () {
    function ShowLoadingModule() {
    }
    ShowLoadingModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [],
                    exports: [],
                    providers: [
                        LoadingController,
                        {
                            provide: LoadingDefault,
                            useClass: ShowLoadingService
                        }
                    ]
                },] }
    ];
    return ShowLoadingModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var FndModule = /** @class */ (function () {
    function FndModule() {
    }
    /**
     * @param {?} config
     * @return {?}
     */
    FndModule.forRoot = /**
     * @param {?} config
     * @return {?}
     */
    function (config) {
        return {
            ngModule: FndModule,
            providers: [GlobalService, { provide: INTL_CONFIG, useValue: config }],
        };
    };
    FndModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        IntlModule,
                        ShowMessageModule,
                        InterceptorModule,
                        DateTimeModule$1,
                        ShowLoadingModule,
                    ],
                    declarations: [],
                    exports: [
                        IntlModule,
                        ShowMessageModule,
                        InterceptorModule,
                        DateTimeModule$1,
                        ShowLoadingModule,
                    ],
                },] }
    ];
    return FndModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FndModule, DateTimeModule$1 as DateTimeModule, GlobalService, InterceptorModule, DefaultHttpInterceptorService, i18nFactory, IntlLiteralsLoaderService, IntlModule, I18NPipe, IntlService, INTL_CONFIG, createTranslateLoader, ShowMessageModule, ShowMessageService, ShowLoadingService, ShowLoadingModule };

//# sourceMappingURL=totvs-log-mobile-foundation.js.map